"""
MQClient - Generic ZeroMQ client library for the Hydra Router system.

This module will be implemented in Task 3.1.
"""


class MQClient:
    """Placeholder - will be implemented in Task 3.1."""

    pass
