"""
Custom exceptions for the Hydra Router system.

This module will be implemented in Task 2.3.
"""


# Placeholder - will be implemented in Task 2.3
class HydraRouterError(Exception):
    """Base exception for Hydra Router errors."""

    pass
